@@ -1,14 +1,24 @@
 package Crypt::SMIME;
 use warnings;
 use strict;
+use Exporter 'import';
+use XSLoader;
 
-our $VERSION = '0.15';
+our %EXPORT_TAGS = (
+    constants => [qw(
+        NO_CHECK_CERTIFICATE
+
+        FORMAT_ASN1
+        FORMAT_PEM
+        FORMAT_SMIME
+       )]
+   );
+Exporter::export_ok_tags('constants');
+
+our $VERSION = '0.16';
 
-require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
 
-__PACKAGE__->_init;
-
 1;
 
 sub sign {
